==> mpqc_2.0.4.orig.tar.gz: mpqc-2.0.4.orig/src/lib/chemistry/qc/oint3/i0211AB.cc <==
#include <chemistry/qc/oint3/build.h>
int BuildIntV3::i0211eAB(){
/* the cost is 117 */
double t1;
double t2;
double t3;
double t4;
double t5;
double t6;
double t7;
double t8;
double t9;
double t10;
double t11;
double t12;
double t13;
double t14;
double t15;
double t16;
double t17;
double t18;
double t19;
double t20;
double t21;
double t22;
double t23;
double t24;
double t25;
double t26;
double t27;
double t28;
double t29;
double t30;
double t31;
t1=int_v_W0-int_v_p120;
double***int_v_list0=int_v_list(0);
double**int_v_list00=int_v_list0[0];
double*int_v_list002=int_v_list00[2];
t2=t1*int_v_list002[0];
t3=0.5*int_v_ooze;
t4=t3*t2;
t2=int_v_W0-int_v_p340;
t5=t2*int_v_list002[0];
t6=int_v_p340-int_v_r30;
double*int_v_list001=int_v_list00[1];
t7=t6*int_v_list001[0];
t8=t7+t5;
t5=int_v_zeta34*int_v_ooze;
t7=int_v_oo2zeta12*t5;
t5=(-1)*t7;
t7=t5*t8;
t9=t7+t4;
t10=t2*int_v_list001[0];
double*int_v_list000=int_v_list00[0];
t11=t6*int_v_list000[0];
t12=t11+t10;
double**int_v_list01=int_v_list0[1];
double*int_v_list010=int_v_list01[0];
int_v_list010[2]=t12;
t10=int_v_oo2zeta12*t12;
t11=t10+t9;
t9=t3*int_v_list002[0];
double*int_v_list003=int_v_list00[3];
t12=t2*int_v_list003[0];
t2=t6*int_v_list002[0];
t6=t2+t12;
t2=t1*t6;
t12=t2+t9;
t2=t1*t12;
t13=t2+t11;
double***int_v_list2=int_v_list(2);
double**int_v_list21=int_v_list2[1];
double*int_v_list210=int_v_list21[0];
int_v_list210[17]=t13;
t2=int_v_W2-int_v_p342;
t11=t2*int_v_list002[0];
t14=int_v_p342-int_v_r32;
t15=t14*int_v_list001[0];
t16=t15+t11;
t11=t5*t16;
t15=t2*int_v_list001[0];
t17=t14*int_v_list000[0];
t18=t17+t15;
int_v_list010[1]=t18;
t15=int_v_oo2zeta12*t18;
t17=t15+t11;
t18=t2*int_v_list003[0];
t2=t14*int_v_list002[0];
t14=t2+t18;
t2=t1*t14;
t18=t1*t2;
t19=t18+t17;
int_v_list210[16]=t19;
t18=int_v_W1-int_v_p341;
t20=t18*int_v_list002[0];
t21=int_v_p341-int_v_r31;
t22=t21*int_v_list001[0];
t23=t22+t20;
t20=t5*t23;
t5=t18*int_v_list001[0];
t22=t21*int_v_list000[0];
t24=t22+t5;
int_v_list010[0]=t24;
t5=int_v_oo2zeta12*t24;
t22=t5+t20;
t24=t18*int_v_list003[0];
t18=t21*int_v_list002[0];
t21=t18+t24;
t18=t1*t21;
t24=t1*t18;
t25=t24+t22;
int_v_list210[15]=t25;
t24=int_v_W2-int_v_p122;
t26=t24*t12;
int_v_list210[14]=t26;
t27=t24*t2;
t28=t4+t27;
int_v_list210[13]=t28;
t27=t24*t18;
int_v_list210[12]=t27;
t29=int_v_W1-int_v_p121;
t30=t12*t29;
int_v_list210[11]=t30;
t12=t29*t2;
int_v_list210[10]=t12;
t2=t29*t18;
t18=t4+t2;
int_v_list210[9]=t18;
t2=t10+t7;
t4=t24*t6;
t7=t24*t4;
t4=t7+t2;
int_v_list210[8]=t4;
t7=t24*int_v_list002[0];
t10=t3*t7;
t7=t11+t10;
t10=t15+t7;
t7=t24*t14;
t11=t9+t7;
t7=t24*t11;
t11=t7+t10;
int_v_list210[7]=t11;
t7=t24*t21;
t10=t24*t7;
t7=t22+t10;
int_v_list210[6]=t7;
t10=t29*t6;
t6=t24*t10;
int_v_list210[5]=t6;
t15=t29*t14;
t14=t24*t15;
t22=t29*int_v_list002[0];
t31=t3*t22;
t22=t31+t14;
int_v_list210[4]=t22;
t14=t29*t21;
t21=t9+t14;
t9=t24*t21;
int_v_list210[3]=t9;
t14=t29*t10;
t10=t2+t14;
int_v_list210[2]=t10;
t2=t29*t15;
t14=t17+t2;
int_v_list210[1]=t14;
t2=t20+t31;
t15=t5+t2;
t2=t29*t21;
t5=t2+t15;
int_v_list210[0]=t5;
t2=t3*int_v_list001[0];
t3=t1*t8;
t15=t3+t2;
double***int_v_list1=int_v_list(1);
double**int_v_list11=int_v_list1[1];
double*int_v_list110=int_v_list11[0];
int_v_list110[8]=t15;
t3=t1*t16;
int_v_list110[7]=t3;
t17=t1*t23;
int_v_list110[6]=t17;
t1=t24*t8;
int_v_list110[5]=t1;
t20=t24*t16;
t21=t2+t20;
int_v_list110[4]=t21;
t20=t24*t23;
int_v_list110[3]=t20;
t24=t29*t8;
int_v_list110[2]=t24;
t8=t29*t16;
int_v_list110[1]=t8;
t16=t29*t23;
t23=t2+t16;
int_v_list110[0]=t23;
return 1;}

==> mpqc_2.3.1.orig.tar.gz: mpqc-2.3.1/src/lib/chemistry/qc/oint3/i0211AB.cc <==
#include <chemistry/qc/oint3/build.h>
int sc::BuildIntV3::i0211eAB(){
/* the cost is 117 */
double t1;
double t2;
double t3;
double t4;
double t5;
double t6;
double t7;
double t8;
double t9;
double t10;
double t11;
double t12;
double t13;
double t14;
double t15;
double t16;
double t17;
double t18;
double t19;
double t20;
double t21;
double t22;
double t23;
double t24;
double t25;
double t26;
double t27;
double t28;
double t29;
double t30;
double t31;
t1=int_v_W0-int_v_p120;
double***restrictxx int_v_list0=int_v_list(0);
double**restrictxx int_v_list00=int_v_list0[0];
double*restrictxx int_v_list002=int_v_list00[2];
t2=t1*int_v_list002[0];
t3=0.5*int_v_ooze;
t4=t3*t2;
t2=int_v_W0-int_v_p340;
t5=t2*int_v_list002[0];
t6=int_v_p340-int_v_r30;
double*restrictxx int_v_list001=int_v_list00[1];
t7=t6*int_v_list001[0];
t8=t7+t5;
t5=int_v_zeta34*int_v_ooze;
t7=int_v_oo2zeta12*t5;
t5=(-1)*t7;
t7=t5*t8;
t9=t7+t4;
t10=t2*int_v_list001[0];
double*restrictxx int_v_list000=int_v_list00[0];
t11=t6*int_v_list000[0];
t12=t11+t10;
double**restrictxx int_v_list01=int_v_list0[1];
double*restrictxx int_v_list010=int_v_list01[0];
int_v_list010[2]=t12;
t10=int_v_oo2zeta12*t12;
t11=t10+t9;
t9=t3*int_v_list002[0];
double*restrictxx int_v_list003=int_v_list00[3];
t12=t2*int_v_list003[0];
t2=t6*int_v_list002[0];
t6=t2+t12;
t2=t1*t6;
t12=t2+t9;
t2=t1*t12;
t13=t2+t11;
double***restrictxx int_v_list2=int_v_list(2);
double**restrictxx int_v_list21=int_v_list2[1];
double*restrictxx int_v_list210=int_v_list21[0];
int_v_list210[17]=t13;
t2=int_v_W2-int_v_p342;
t11=t2*int_v_list002[0];
t14=int_v_p342-int_v_r32;
t15=t14*int_v_list001[0];
t16=t15+t11;
t11=t5*t16;
t15=t2*int_v_list001[0];
t17=t14*int_v_list000[0];
t18=t17+t15;
int_v_list010[1]=t18;
t15=int_v_oo2zeta12*t18;
t17=t15+t11;
t18=t2*int_v_list003[0];
t2=t14*int_v_list002[0];
t14=t2+t18;
t2=t1*t14;
t18=t1*t2;
t19=t18+t17;
int_v_list210[16]=t19;
t18=int_v_W1-int_v_p341;
t20=t18*int_v_list002[0];
t21=int_v_p341-int_v_r31;
t22=t21*int_v_list001[0];
t23=t22+t20;
t20=t5*t23;
t5=t18*int_v_list001[0];
t22=t21*int_v_list000[0];
t24=t22+t5;
int_v_list010[0]=t24;
t5=int_v_oo2zeta12*t24;
t22=t5+t20;
t24=t18*int_v_list003[0];
t18=t21*int_v_list002[0];
t21=t18+t24;
t18=t1*t21;
t24=t1*t18;
t25=t24+t22;
int_v_list210[15]=t25;
t24=int_v_W2-int_v_p122;
t26=t24*t12;
int_v_list210[14]=t26;
t27=t24*t2;
t28=t4+t27;
int_v_list210[13]=t28;
t27=t24*t18;
int_v_list210[12]=t27;
t29=int_v_W1-int_v_p121;
t30=t12*t29;
int_v_list210[11]=t30;
t12=t29*t2;
int_v_list210[10]=t12;
t2=t29*t18;
t18=t4+t2;
int_v_list210[9]=t18;
t2=t10+t7;
t4=t24*t6;
t7=t24*t4;
t4=t7+t2;
int_v_list210[8]=t4;
t7=t24*int_v_list002[0];
t10=t3*t7;
t7=t11+t10;
t10=t15+t7;
t7=t24*t14;
t11=t9+t7;
t7=t24*t11;
t11=t7+t10;
int_v_list210[7]=t11;
t7=t24*t21;
t10=t24*t7;
t7=t22+t10;
int_v_list210[6]=t7;
t10=t29*t6;
t6=t24*t10;
int_v_list210[5]=t6;
t15=t29*t14;
t14=t24*t15;
t22=t29*int_v_list002[0];
t31=t3*t22;
t22=t31+t14;
int_v_list210[4]=t22;
t14=t29*t21;
t21=t9+t14;
t9=t24*t21;
int_v_list210[3]=t9;
t14=t29*t10;
t10=t2+t14;
int_v_list210[2]=t10;
t2=t29*t15;
t14=t17+t2;
int_v_list210[1]=t14;
t2=t20+t31;
t15=t5+t2;
t2=t29*t21;
t5=t2+t15;
int_v_list210[0]=t5;
t2=t3*int_v_list001[0];
t3=t1*t8;
t15=t3+t2;
double***restrictxx int_v_list1=int_v_list(1);
double**restrictxx int_v_list11=int_v_list1[1];
double*restrictxx int_v_list110=int_v_list11[0];
int_v_list110[8]=t15;
t3=t1*t16;
int_v_list110[7]=t3;
t17=t1*t23;
int_v_list110[6]=t17;
t1=t24*t8;
int_v_list110[5]=t1;
t20=t24*t16;
t21=t2+t20;
int_v_list110[4]=t21;
t20=t24*t23;
int_v_list110[3]=t20;
t24=t29*t8;
int_v_list110[2]=t24;
t8=t29*t16;
int_v_list110[1]=t8;
t16=t29*t23;
t23=t2+t16;
int_v_list110[0]=t23;
return 1;}
